@@ -8,8 +8,20 @@ import gobject
 import logging
 log = logging.getLogger("Conduit")
 
-import conduit.Utils as Utils
+import conduit
+import conduit.utils as Utils
 
+CONFLICT_POLICY_NAMES = ("conflict", "deleted")
+CONFLICT_POLICY_VALUES = ("ask","skip","replace")
+CONFLICT_POLICY_VALUE_ICONS = {
+    "conflict_ask"      :   "conduit-conflict-ask",
+    "conflict_skip"     :   "conduit-conflict-skip",
+    "conflict_replace"  :   "conduit-conflict-right",
+    "deleted_ask"       :   "conduit-conflict-ask",
+    "deleted_skip"      :   "conduit-conflict-skip",
+    "deleted_replace"   :   "conduit-conflict-delete"
+}
+    
 class Conduit(gobject.GObject):
     """
     Model of a Conduit, which is a one-to-many bridge of DataSources to
@@ -47,7 +59,8 @@ class Conduit(gobject.GObject):
             gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, []),
         "sync-progress": (
             gobject.SIGNAL_RUN_LAST, gobject.TYPE_NONE, [
-            gobject.TYPE_FLOAT])        #percent complete
+            gobject.TYPE_FLOAT,         #percent complete
+            gobject.TYPE_PYOBJECT])     #list of successfully completed UIDs
         }
 
     def __init__(self, syncManager, uid=""):
@@ -67,10 +80,18 @@ class Conduit(gobject.GObject):
         #a conduit can hold one datasource and many datasinks (wrappers)
         self.datasource = None
         self.datasinks = []
-
         self.twoWaySyncEnabled = False
         self.slowSyncEnabled = False
         self.autoSyncEnabled = False
+        self.conflictPolicy = ""
+        self.deletedPolicy = ""
+
+        #set conduits to have the default conflict/deleted policy
+        for policyName in CONFLICT_POLICY_NAMES:
+            policyValue = conduit.GLOBALS.settings.get("default_policy_%s" % policyName)
+            self.set_policy(policyName,policyValue)
+
+        self._conflicts = {}
 
     def _parameters_changed(self):
         self.emit("parameters-changed")
@@ -248,6 +269,24 @@ class Conduit(gobject.GObject):
     def do_auto_sync(self):
         return self.autoSyncEnabled
 
+    def get_policy(self, policy):
+        if policy not in CONFLICT_POLICY_NAMES:
+            raise Exception("Unknown policy: %s" % policy)
+        if policy == "conflict":
+            return self.conflictPolicy
+        else:
+            return self.deletedPolicy
+        
+    def set_policy(self, policy, value):
+        if policy not in CONFLICT_POLICY_NAMES:
+            raise Exception("Unknown policy: %s" % policy)
+        if value not in CONFLICT_POLICY_VALUES:
+            raise Exception("Unknown policy value: %s" % policy)
+        if policy == "conflict":
+            self.conflictPolicy = value
+        else:
+            self.deletedPolicy = value
+
     def change_dataprovider(self, oldDpw, newDpw):
         """
         called when dpw becomes unavailable.
@@ -260,7 +299,7 @@ class Conduit(gobject.GObject):
                     )
         if newDpw.module != None:
             newDpw.module.connect("change-detected", self._change_detected)
-        
+
         self.emit("dataprovider-changed", oldDpw, newDpw) 
 
     def refresh_dataprovider(self, dp, block=False):
@@ -287,4 +326,15 @@ class Conduit(gobject.GObject):
         else:
             log.info("Conduit must have a datasource and a datasink")
 
+    def emit_conflict(self, conflict):
+        hc = hash(conflict)
+        if hc not in self._conflicts:
+            self._conflicts[hc] = conflict
+            self.emit("sync-conflict", conflict)
 
+    def resolved_conflict(self, conflict):
+        try:
+            hc = hash(conflict)
+            del(self._conflicts[hc])
+        except KeyError:
+            log.warn("Unknown conflict")
