@@ -8,18 +8,19 @@ License: GPLv2
 import os.path
 import dbus
 import dbus.service
-import dbus.glib
 import logging
 log = logging.getLogger("DBus")
 
 import conduit
-import conduit.Utils as Utils
+import conduit.utils as Utils
 import conduit.Conduit as Conduit
 import conduit.SyncSet as SyncSet
 
 ERROR = -1
 SUCCESS = 0
 
+DEBUG_ALL_CALLS = True
+
 APPLICATION_DBUS_IFACE="org.conduit.Application"
 SYNCSET_DBUS_IFACE="org.conduit.SyncSet"
 CONDUIT_DBUS_IFACE="org.conduit.Conduit"
@@ -80,7 +81,7 @@ DATAPROVIDER_DBUS_IFACE="org.conduit.DataProvider"
 # SyncStarted
 # SyncCompleted(aborted, error, conflict)
 # SyncConflict
-# SyncProgress(progress)
+# SyncProgress(progress, completedUIDs)
 # DataproviderAdded
 # DataproviderRemoved
 #
@@ -129,7 +130,8 @@ class DBusItem(dbus.service.Object):
         return self.__dbus_object_path__
 
     def _print(self, message):
-        log.debug("DBus Message from %s: %s" % (self.get_path(), message))
+        if DEBUG_ALL_CALLS:
+            log.debug("DBus Message from %s: %s" % (self.get_path(), message))
 
 class ConduitDBusItem(DBusItem):
     def __init__(self, sync_manager, conduit, uuid):
@@ -151,9 +153,9 @@ class ConduitDBusItem(DBusItem):
         if cond == self.conduit:
             self.SyncCompleted(bool(aborted), bool(error), bool(conflict))
 
-    def _on_sync_progress(self, cond, progress):
+    def _on_sync_progress(self, cond, progress, UIDs):
         if cond == self.conduit:
-            self.SyncProgress(float(progress))
+            self.SyncProgress(float(progress), UIDs)
 
     def _on_sync_conflict(self, cond, conflict):
         if cond == self.conduit:
@@ -226,9 +228,9 @@ class ConduitDBusItem(DBusItem):
     def SyncConflict(self):
         self._print("SyncConflict")
 
-    @dbus.service.signal(CONDUIT_DBUS_IFACE, signature='d')
-    def SyncProgress(self, progress):
-        self._print("SyncProgress %s%%" % (progress*100.0))
+    @dbus.service.signal(CONDUIT_DBUS_IFACE, signature='das')
+    def SyncProgress(self, progress, UIDs):
+        self._print("SyncProgress %s%%\n\t%s" % ((progress*100.0), UIDs))
 
     #
     # org.conduit.Exporter
