@@ -1,12 +1,9 @@
-APPVERSION = "0.3.8"
-APPNAME = "conduit"
+VERSION = "0.3.12"
 PYTHONDIR = "/usr/local/lib/python2.5/site-packages"
+BIN_DIR = "/usr/local/bin"
+LIB_DIR = "/usr/local/lib"
 LOCALE_DIR = "${prefix}/share/locale"
 SHARED_DATA_DIR = "/usr/local/share/conduit"
 SHARED_MODULE_DIR = "/usr/local/lib/conduit/modules"
 
-BIN_DIR = "/usr/local/bin"
-DATA_DIR = "@DATADIR@"
-LIB_DIR = "/usr/local/lib"
-
 
