@@ -3,7 +3,9 @@ import logging
 log = logging.getLogger("modules.AVConverter")
 
 import conduit
-import conduit.Utils as Utils
+import conduit.utils as Utils
+import conduit.utils.CommandLineConverter as CommandLineConverter
+import conduit.TypeConverter as TypeConverter
 import conduit.datatypes.File as File
 import conduit.datatypes.Audio as Audio
 import conduit.datatypes.Video as Video
@@ -15,9 +17,9 @@ if Utils.program_installed("ffmpeg"):
 else:
     MODULES = {}
 
-class FFmpegCommandLineConverter(Utils.CommandLineConverter):
+class FFmpegCommandLineConverter(CommandLineConverter.CommandLineConverter):
     def __init__(self, duration=None):
-        Utils.CommandLineConverter.__init__(self)
+        CommandLineConverter.CommandLineConverter.__init__(self)
         self.duration = duration
         self.percentage_match = re.compile('time=?(\d+\.\d+)')
 
@@ -50,9 +52,9 @@ class FFmpegCommandLineConverter(Utils.CommandLineConverter):
     def check_cancelled(self):
         return conduit.GLOBALS.cancelled
 
-class MencoderCommandLineConverter(Utils.CommandLineConverter):
+class MencoderCommandLineConverter(CommandLineConverter.CommandLineConverter):
     def __init__(self):
-        Utils.CommandLineConverter.__init__(self)
+        CommandLineConverter.CommandLineConverter.__init__(self)
         self.percentage_match = re.compile('(\d+)%')
 
     def build_command(self, **kwargs):
@@ -88,7 +90,7 @@ class MencoderCommandLineConverter(Utils.CommandLineConverter):
     def check_cancelled(self):
         return conduit.GLOBALS.cancelled
             
-class AudioVideoConverter:
+class AudioVideoConverter(TypeConverter.Converter):
 
     #These commands are run to determine attributes about the file 
     #(such as size and duration) prior to transcode. They should be
@@ -114,7 +116,7 @@ class AudioVideoConverter:
         input_file = video.get_local_uri()
         
         #run ffmpeg over the video to work out its format, and duration
-        c = Utils.CommandLineConverter()
+        c = CommandLineConverter.CommandLineConverter()
         c.build_command(AudioVideoConverter.VIDEO_INSPECT_COMMAND)
         ok,output = c.convert(input_file,"/dev/null",save_output=True)
 
@@ -174,7 +176,7 @@ class AudioVideoConverter:
         input_file = audio.get_local_uri()
 
         #run ffmpeg over the video to work out its format, and duration
-        c = Utils.CommandLineConverter()
+        c = CommandLineConverter.CommandLineConverter()
         c.build_command(AudioVideoConverter.AUDIO_INSPECT_COMMAND)
         ok,output = c.convert(input_file,"/dev/null",save_output=True)
 
