@@ -9,12 +9,12 @@ import conduit.dataproviders.DataProviderCategory as DataProviderCategory
 import conduit.dataproviders.File as FileDataProvider
 import conduit.dataproviders.VolumeFactory as VolumeFactory
 import conduit.dataproviders.AutoSync as AutoSync
-import conduit.Utils as Utils
+import conduit.utils as Utils
 import conduit.Vfs as Vfs
 
 MODULES = {
-	"FileSource" :              { "type": "dataprovider" },
-	"FolderTwoWay" :            { "type": "dataprovider" },
+    "FileSource" :              { "type": "dataprovider" },
+    "FolderTwoWay" :            { "type": "dataprovider" },
     "RemovableDeviceFactory" :  { "type": "dataprovider-factory" }
 }
 
@@ -22,6 +22,7 @@ class FileSource(FileDataProvider.FileSource):
 
     _name_ = _("Files")
     _description_ = _("Source for synchronizing multiple files")
+    _configurable_ = True
 
     def __init__(self, *args):
         FileDataProvider.FileSource.__init__(self)
@@ -61,18 +62,21 @@ class FolderTwoWay(FileDataProvider.FolderTwoWay, AutoSync.AutoSync):
 
     _name_ = _("Folder")
     _description_ = _("Synchronize folders")
+    _configurable_ = True
 
     DEFAULT_FOLDER = "file://"+os.path.expanduser("~")
     DEFAULT_GROUP = "Home"
     DEFAULT_HIDDEN = False
     DEFAULT_COMPARE_IGNORE_MTIME = False
+    DEFAULT_FOLLOW_SYMLINKS = False
 
     def __init__(self, *args):
         FileDataProvider.FolderTwoWay.__init__(self,
                 self.DEFAULT_FOLDER,
                 self.DEFAULT_GROUP,
                 self.DEFAULT_HIDDEN,
-                self.DEFAULT_COMPARE_IGNORE_MTIME
+                self.DEFAULT_COMPARE_IGNORE_MTIME,
+                self.DEFAULT_FOLLOW_SYMLINKS
                 )
         AutoSync.AutoSync.__init__(self)
         self._monitor_folder_id = None
@@ -85,31 +89,35 @@ class FolderTwoWay(FileDataProvider.FolderTwoWay, AutoSync.AutoSync):
     def configure(self, window):
         Utils.dataprovider_add_dir_to_path(__file__, "")
         import FileConfiguration
-        f = FileConfiguration._FolderTwoWayConfigurator(window, self.folder, self.folderGroupName, self.includeHidden, self.compareIgnoreMtime)
-        self.folder, self.folderGroupName, self.includeHidden, self.compareIgnoreMtime = f.show_dialog()
+        f = FileConfiguration._FolderTwoWayConfigurator(
+                                    window,
+                                    self.folder,
+                                    self.includeHidden,
+                                    self.compareIgnoreMtime,
+                                    self.followSymlinks)
+        self.folder, self.includeHidden, self.compareIgnoreMtime, self.followSymlinks = f.show_dialog()
         self._monitor_folder()
         
     def set_configuration(self, config):
         self.folder = config.get("folder", self.DEFAULT_FOLDER)
-        self.folderGroupName = config.get("folderGroupName", self.DEFAULT_GROUP)
         self.includeHidden = config.get("includeHidden", self.DEFAULT_HIDDEN)
         self.compareIgnoreMtime = config.get("compareIgnoreMtime", self.DEFAULT_COMPARE_IGNORE_MTIME)
+        self.followSymlinks = config.get("followSymlinks", self.DEFAULT_FOLLOW_SYMLINKS)        
         self._monitor_folder()
 
     def get_configuration(self):
-        #_save_config_file_for_dir(self.folder, self.folderGroupName)
         return {
             "folder" : self.folder,
-            "folderGroupName" : self.folderGroupName,
             "includeHidden" : self.includeHidden,
-            "compareIgnoreMtime" : self.compareIgnoreMtime
+            "compareIgnoreMtime" : self.compareIgnoreMtime,
+            "followSymlinks" : self.followSymlinks
             }
 
     def get_UID(self):
-        return "%s:%s" % (self.folder, self.folderGroupName)
+        return self.folder
         
     def get_name(self):
-        return self.folderGroupName
+        return Vfs.uri_get_filename(self.folder)
 
     def _monitor_folder(self):
         if self._monitor_folder_id != None:
@@ -144,7 +152,6 @@ class RemovableDeviceFactory(VolumeFactory.VolumeFactory):
             "_udi_"         :   udi
         }
         if name:
-            info["DEFAULT_GROUP"] = name
             info["_name_"] = name            
         
         klass = type(
@@ -160,7 +167,7 @@ class RemovableDeviceFactory(VolumeFactory.VolumeFactory):
         the folder and the udi to allow multiple preconfigured groups per
         usb key
         """
-        VolumeFactory.VolumeFactory.emit_added(self, 
+        return VolumeFactory.VolumeFactory.emit_added(self, 
                         klass, 
                         initargs, 
                         category, 
@@ -173,11 +180,24 @@ class RemovableDeviceFactory(VolumeFactory.VolumeFactory):
             if prop2.has_key("storage.removable") and prop2["storage.removable"] == True:
                 mount,label = self._get_device_info(props)
                 log.info("Detected removable volume %s@%s" % (label,mount))
+
+                #short circuit the logic here to test if this is a volume being
+                #unmounted. Its still interesting, we just dont make a 
+                #klass for it
+                if udi in self._volumes and not mount:
+                    log.debug("This is a FileModule being removed")
+                    del(self._volumes[udi])
+                    return True
+
                 #check for the presence of a mount/.conduit group file
                 #which describe the folder sync groups, and their names,
                 mountUri = "file://%s" % mount
-                
-                groups = FileDataProvider.read_removable_volume_group_file(mountUri)
+                try:
+                    groups = FileDataProvider.read_removable_volume_group_file(mountUri)
+                except Exception, e:
+                    log.warn("Error reading volume group file: %s" % e)
+                    groups = ()
+                    
                 if len(groups) > 0:
                     self._volumes[udi] = []
                     for relativeUri,name in groups:
